@@ -2,26 +2,21 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
-use glib::translate::*;
 use gio::AppInfo;
-use ffi;
-use glib_ffi;
-use gobject_ffi;
-use std::ptr;
-use std::mem;
-
 use glib::object::IsA;
+use glib::translate::*;
+use gtk_sys;
 use Widget;
 
 glib_wrapper! {
-    pub struct AppChooser(Object<ffi::GtkAppChooser>): Widget;
+    pub struct AppChooser(Interface<gtk_sys::GtkAppChooser>) @requires Widget;
 
     match fn {
-        get_type => || ffi::gtk_app_chooser_get_type(),
+        get_type => || gtk_sys::gtk_app_chooser_get_type(),
     }
 }
 
-pub trait AppChooserExt {
+pub trait AppChooserExt: 'static {
     fn get_app_info(&self) -> Option<AppInfo>;
     fn get_content_type(&self) -> Option<String>;
     fn refresh(&self);
@@ -29,17 +24,22 @@ pub trait AppChooserExt {
 
 impl<O: IsA<AppChooser>> AppChooserExt for O {
     fn get_app_info(&self) -> Option<AppInfo> {
-        unsafe { from_glib_full(ffi::gtk_app_chooser_get_app_info(self.to_glib_none().0)) }
+        unsafe {
+            from_glib_full(gtk_sys::gtk_app_chooser_get_app_info(
+                self.as_ref().to_glib_none().0,
+            ))
+        }
     }
 
     fn get_content_type(&self) -> Option<String> {
         unsafe {
-            from_glib_full(
-                ffi::gtk_app_chooser_get_content_type(self.to_glib_none().0))
+            from_glib_full(gtk_sys::gtk_app_chooser_get_content_type(
+                self.as_ref().to_glib_none().0,
+            ))
         }
     }
 
     fn refresh(&self) {
-        unsafe { ffi::gtk_app_chooser_refresh(self.to_glib_none().0) }
+        unsafe { gtk_sys::gtk_app_chooser_refresh(self.as_ref().to_glib_none().0) }
     }
 }
