@@ -2,28 +2,26 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
-use ffi;
 use glib::translate::*;
-use glib_ffi;
-use gobject_ffi;
-use std::mem;
-use std::ptr;
+use gtk_sys;
 use std::fmt;
 use std::ops;
 
 glib_wrapper! {
     #[derive(PartialEq, Eq, PartialOrd, Ord, Hash)]
-    pub struct Border(Boxed<ffi::GtkBorder>);
+    pub struct Border(Boxed<gtk_sys::GtkBorder>);
 
     match fn {
-        copy => |ptr| ffi::gtk_border_copy(mut_override(ptr)),
-        free => |ptr| ffi::gtk_border_free(ptr),
-        get_type => || ffi::gtk_border_get_type(),
+        copy => |ptr| gtk_sys::gtk_border_copy(mut_override(ptr)),
+        free => |ptr| gtk_sys::gtk_border_free(ptr),
+        init => |_ptr| (),
+        clear => |_ptr| (),
+        get_type => || gtk_sys::gtk_border_get_type(),
     }
 }
 
 impl ops::Deref for Border {
-    type Target = ffi::GtkBorder;
+    type Target = gtk_sys::GtkBorder;
 
     fn deref(&self) -> &Self::Target {
         &(*self.0)
@@ -36,13 +34,10 @@ impl ops::DerefMut for Border {
     }
 }
 
-
 impl Border {
     pub fn new() -> Border {
         assert_initialized_main_thread!();
-        unsafe {
-            from_glib_full(ffi::gtk_border_new())
-        }
+        unsafe { from_glib_full(gtk_sys::gtk_border_new()) }
     }
 }
 
