@@ -1,5 +1,5 @@
-use ffi;
 use glib::translate::*;
+use gtk_sys;
 use std::mem;
 
 #[repr(C)]
@@ -17,23 +17,23 @@ impl Uninitialized for Requisition {
 }
 
 #[doc(hidden)]
-impl<'a> ToGlibPtr<'a, *const ffi::GtkRequisition> for Requisition {
+impl<'a> ToGlibPtr<'a, *const gtk_sys::GtkRequisition> for Requisition {
     type Storage = &'a Self;
 
     #[inline]
-    fn to_glib_none(&'a self) -> Stash<'a, *const ffi::GtkRequisition, Self> {
+    fn to_glib_none(&'a self) -> Stash<'a, *const gtk_sys::GtkRequisition, Self> {
         let ptr: *const Requisition = &*self;
-        Stash(ptr as *const ffi::GtkRequisition, self)
+        Stash(ptr as *const gtk_sys::GtkRequisition, self)
     }
 }
 
 #[doc(hidden)]
-impl<'a> ToGlibPtrMut<'a, *mut ffi::GtkRequisition> for Requisition {
+impl<'a> ToGlibPtrMut<'a, *mut gtk_sys::GtkRequisition> for Requisition {
     type Storage = &'a mut Self;
 
     #[inline]
-    fn to_glib_none_mut(&'a mut self) -> StashMut<'a, *mut ffi::GtkRequisition, Self> {
+    fn to_glib_none_mut(&'a mut self) -> StashMut<'a, *mut gtk_sys::GtkRequisition, Self> {
         let ptr: *mut Requisition = &mut *self;
-        StashMut(ptr as *mut ffi::GtkRequisition, self)
+        StashMut(ptr as *mut gtk_sys::GtkRequisition, self)
     }
 }
