@@ -2,17 +2,18 @@
 // See the COPYRIGHT file at the top-level directory of this distribution.
 // Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
 
-use ffi;
 use glib::translate::*;
+use gtk_sys;
 use TextAttributes;
 use TextIter;
 
 impl TextIter {
     pub fn get_attributes(&self, values: &TextAttributes) -> bool {
         unsafe {
-            from_glib(
-                ffi::gtk_text_iter_get_attributes(self.to_glib_none().0,
-                    mut_override(values.to_glib_none().0)))
+            from_glib(gtk_sys::gtk_text_iter_get_attributes(
+                self.to_glib_none().0,
+                mut_override(values.to_glib_none().0),
+            ))
         }
     }
 }
